@@ -102,6 +102,7 @@
 #define PFD_SUPPORT_COMPOSITION  0x00008000
 #endif
 
+
 typedef struct  {
     int notOpenGL;
     int unknownPixelType;
@@ -680,19 +681,9 @@ glxWinScreenProbe(ScreenPtr pScreen)
     // might have completely different capabilities.  Of course, good luck getting
     // those screens to be accelerated in XP and earlier...
 
-    {
-        // testing facility to not use any WGL extensions
-        char *envptr = getenv("GLWIN_NO_WGL_EXTENSIONS");
-
-        if ((envptr != NULL) && (atoi(envptr) != 0)) {
-            ErrorF("GLWIN_NO_WGL_EXTENSIONS is set, ignoring WGL_EXTENSIONS\n");
-            wgl_extensions = "";
-        }
-    }
 
     {
         int i;
-        Bool glx_sgi_make_current_read = FALSE;
 
         const struct
         {
@@ -700,13 +691,13 @@ glxWinScreenProbe(ScreenPtr pScreen)
             const char *glxext;
             Bool mandatory;
         } extensionMap[] = {
-            { "WGL_ARB_make_current_read", "GLX_SGI_make_current_read", 0 },
+            { "WGL_ARB_make_current_read", "GLX_SGI_make_current_read", 1 },
             { "WGL_EXT_swap_control", "GLX_SGI_swap_control", 0 },
             { "WGL_EXT_swap_control", "GLX_MESA_swap_control", 0 },
             //      { "WGL_ARB_render_texture", "GLX_EXT_texture_from_pixmap", 0 },
             // Sufficiently different that it's not obvious if this can be done...
-            { "WGL_ARB_pbuffer", "GLX_SGIX_pbuffer", 0 },
-            { "WGL_ARB_multisample", "GLX_ARB_multisample", 0 },
+            { "WGL_ARB_pbuffer", "GLX_SGIX_pbuffer", 1 },
+            { "WGL_ARB_multisample", "GLX_ARB_multisample", 1 },
             { "WGL_ARB_multisample", "GLX_SGIS_multisample", 0 },
             { "WGL_ARB_pixel_format_float", "GLX_ARB_fbconfig_float", 0 },
             { "WGL_EXT_pixel_format_packed_float", "GLX_EXT_fbconfig_packed_float", 0 },
@@ -720,13 +711,7 @@ glxWinScreenProbe(ScreenPtr pScreen)
         //
         // Based on the WGL extensions available, enable various GLX extensions
         //
-        memset(screen->glx_enable_bits, 0, __GLX_EXT_BYTES);
-
-        __glXEnableExtension(screen->glx_enable_bits, "GLX_EXT_visual_info");
-        __glXEnableExtension(screen->glx_enable_bits, "GLX_EXT_visual_rating");
-        __glXEnableExtension(screen->glx_enable_bits, "GLX_EXT_import_context");
-        __glXEnableExtension(screen->glx_enable_bits, "GLX_OML_swap_method");
-        __glXEnableExtension(screen->glx_enable_bits, "GLX_SGIX_fbconfig");
+        __glXInitExtensionEnableBits(screen->base.glx_enable_bits);
 
         for (i = 0; i < sizeof(extensionMap)/sizeof(extensionMap[0]); i++) {
             if (strstr(wgl_extensions, extensionMap[i].wglext)) {
@@ -738,25 +723,22 @@ glxWinScreenProbe(ScreenPtr pScreen)
             }
         }
 
-        if (strstr(wgl_extensions, "WGL_ARB_make_current_read")) {
-            glx_sgi_make_current_read = TRUE;
-        }
-
         // Because it pre-dates WGL_EXT_extensions_string, GL_WIN_swap_hint might
         // only be in GL_EXTENSIONS
         if (strstr(gl_extensions, "GL_WIN_swap_hint")) {
-            __glXEnableExtension(screen->glx_enable_bits,
+            __glXEnableExtension(screen->base.glx_enable_bits,
                                  "GLX_MESA_copy_sub_buffer");
             LogMessage(X_INFO, "AIGLX: enabled GLX_MESA_copy_sub_buffer\n");
         }
 
-        if (strstr(wgl_extensions, "WGL_ARB_pbuffer")) {
-            screen->has_WGL_ARB_pbuffer = TRUE;
-        }
+        if (strstr(wgl_extensions, "WGL_ARB_make_current_read"))
+            screen->has_WGL_ARB_make_current_read = TRUE;
 
-        if (strstr(wgl_extensions, "WGL_ARB_multisample")) {
+        if (strstr(wgl_extensions, "WGL_ARB_pbuffer"))
+            screen->has_WGL_ARB_pbuffer = TRUE;
+
+        if (strstr(wgl_extensions, "WGL_ARB_multisample"))
             screen->has_WGL_ARB_multisample = TRUE;
-        }
 
         if (strstr(wgl_extensions, "WGL_ARB_framebuffer_sRGB")) {
             screen->has_WGL_ARB_framebuffer_sRGB = TRUE;
@@ -803,40 +785,7 @@ glxWinScreenProbe(ScreenPtr pScreen)
         screen->base.numVisuals = 0;
 
         __glXScreenInit(&screen->base, pScreen);
-
-        // Generate the GLX extensions string (overrides that set by __glXScreenInit())
-        {
-            unsigned int buffer_size =
-                __glXGetExtensionString(screen->glx_enable_bits, NULL);
-            if (buffer_size > 0) {
-                free(screen->base.GLXextensions);
-
-                screen->base.GLXextensions = xnfalloc(buffer_size);
-                __glXGetExtensionString(screen->glx_enable_bits,
-                                        screen->base.GLXextensions);
-            }
-        }
-
-        //
-        // Override the GLX version (__glXScreenInit() sets it to "1.2")
-        // if we have all the needed extensions to operate as a higher version
-        //
-        // SGIX_fbconfig && SGIX_pbuffer && SGI_make_current_read -> 1.3
-        // ARB_multisample -> 1.4
-        //
-        if (screen->has_WGL_ARB_pbuffer && glx_sgi_make_current_read) {
-            if (screen->has_WGL_ARB_multisample) {
-                screen->base.GLXmajor = 1;
-                screen->base.GLXminor = 4;
-            }
-            else {
-                screen->base.GLXmajor = 1;
-                screen->base.GLXminor = 3;
-            }
-        }
     }
-    LogMessage(X_INFO, "AIGLX: Set GLX version to %d.%d\n",
-               screen->base.GLXmajor, screen->base.GLXminor);
 
     wglMakeCurrent(NULL, NULL);
     wglDeleteContext(hglrc);
@@ -1556,6 +1505,7 @@ static int
 glxWinContextMakeCurrent(__GLXcontext * base)
 {
     __GLXWinContext *gc = (__GLXWinContext *) base;
+    glxWinScreen *scr = (glxWinScreen *)base->pGlxScreen;
     BOOL ret;
     HDC drawDC;
     HDC readDC = NULL;
@@ -1588,7 +1538,14 @@ glxWinContextMakeCurrent(__GLXcontext * base)
     }
 
     if ((gc->base.readPriv != NULL) && (gc->base.readPriv != gc->base.drawPriv)) {
-        // XXX: should only occur with WGL_ARB_make_current_read
+        /*
+         * We enable GLX_SGI_make_current_read unconditionally, but the
+         * renderer might not support it. It's fairly rare to use this
+         * feature so just error out if it can't work.
+         */
+        if (!scr->has_WGL_ARB_make_current_read)
+            return False;
+
         /*
            If there is a separate read drawable, create a separate read DC, and
            use the wglMakeContextCurrent extension to make the context current drawing
@@ -2112,7 +2069,6 @@ glxWinCreateConfigs(HDC hdc, glxWinScreen * screen)
             c->base.renderType = GLX_RGBA_BIT;
         }
 
-        c->base.xRenderable = GL_TRUE;
         c->base.fbconfigID = -1;        // will be set by __glXScreenInit()
 
         /* SGIX_pbuffer / GLX 1.3 */
@@ -2413,7 +2369,7 @@ glxWinCreateConfigsExt(HDC hdc, glxWinScreen * screen, PixelFormatRejectStats *
 
             if (layers > 0) {
                 ErrorF
-                    ("pixelFormat %d: has %d overlay, %d underlays which aren't currently handled",
+                    ("pixelFormat %d: has %d overlay, %d underlays which aren't currently handled\n",
                      i, ATTR_VALUE(WGL_NUMBER_OVERLAYS_ARB, 0),
                      ATTR_VALUE(WGL_NUMBER_UNDERLAYS_ARB, 0));
                 // XXX: need to iterate over layers?
@@ -2486,7 +2442,6 @@ glxWinCreateConfigsExt(HDC hdc, glxWinScreen * screen, PixelFormatRejectStats *
              | (ATTR_VALUE(WGL_DRAW_TO_BITMAP_ARB, 0) ? GLX_PIXMAP_BIT : 0)
              | (ATTR_VALUE(WGL_DRAW_TO_PBUFFER_ARB, 0) ? GLX_PBUFFER_BIT : 0));
 
-        c->base.xRenderable = GL_TRUE;
         c->base.fbconfigID = -1;        // will be set by __glXScreenInit()
 
         /* SGIX_pbuffer / GLX 1.3 */
@@ -2569,7 +2524,10 @@ glxWinCreateConfigsExt(HDC hdc, glxWinScreen * screen, PixelFormatRejectStats *
         c->base.yInverted = -1;
 
         /* WGL_ARB_framebuffer_sRGB */
-        c->base.sRGBCapable = ATTR_VALUE(WGL_FRAMEBUFFER_SRGB_CAPABLE_ARB, 0);
+        if (screen->has_WGL_ARB_framebuffer_sRGB)
+            c->base.sRGBCapable = ATTR_VALUE(WGL_FRAMEBUFFER_SRGB_CAPABLE_ARB, 0);
+        else
+            c->base.sRGBCapable = 0;
 
         n++;
 
