@@ -62,7 +62,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:339  */
+#line 1 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:339  */
 
 /*
  * Copyright (C) 1994-2000 The XFree86 Project, Inc. All Rights Reserved.
@@ -276,7 +276,7 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 99 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:355  */
+#line 99 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:355  */
 
   char *sVal;
   unsigned long uVal;
@@ -1483,337 +1483,337 @@ yyreduce:
   switch (yyn)
     {
         case 26:
-#line 183 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 183 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetDPI((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
 #line 1489 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 186 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 186 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetXKBLayout((yyvsp[-1].sVal)); }
 #line 1495 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 189 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 189 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetXKBModel((yyvsp[-1].sVal)); }
 #line 1501 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 192 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 192 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetXKBOptions((yyvsp[-1].sVal)); }
 #line 1507 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 195 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 195 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetXKBRules((yyvsp[-1].sVal)); }
 #line 1513 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 198 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 198 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetXKBVariant((yyvsp[-1].sVal)); }
 #line 1519 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 32:
-#line 201 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 201 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetTrayIcon((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
 #line 1525 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 33:
-#line 204 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 204 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetRootMenu((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
 #line 1531 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 34:
-#line 207 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 207 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetDefaultSysMenu((yyvsp[-2].sVal), (yyvsp[-1].iVal)); free((yyvsp[-2].sVal)); }
 #line 1537 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 35:
-#line 210 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 210 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetDefaultIcon((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
 #line 1543 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 36:
-#line 213 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 213 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { SetIconDirectory((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
 #line 1549 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 37:
-#line 216 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 216 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine("-", CMD_SEPARATOR, ""); }
 #line 1555 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 38:
-#line 217 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 217 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine((yyvsp[-3].sVal), CMD_ALWAYSONTOP, ""); free((yyvsp[-3].sVal)); }
 #line 1561 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 39:
-#line 218 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 218 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine((yyvsp[-4].sVal), CMD_EXEC, (yyvsp[-2].sVal)); free((yyvsp[-4].sVal)); free((yyvsp[-2].sVal)); }
 #line 1567 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 40:
-#line 219 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 219 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine((yyvsp[-4].sVal), CMD_MENU, (yyvsp[-2].sVal)); free((yyvsp[-4].sVal)); free((yyvsp[-2].sVal)); }
 #line 1573 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 41:
-#line 220 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 220 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { AddMenuLine((yyvsp[-3].sVal), CMD_RELOAD, ""); free((yyvsp[-3].sVal)); }
 #line 1579 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 44:
-#line 227 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 227 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { OpenMenu((yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
 #line 1585 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 45:
-#line 227 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 227 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     {CloseMenu();}
 #line 1591 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 46:
-#line 230 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 230 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { AddIconLine((yyvsp[-3].sVal), (yyvsp[-2].sVal)); free((yyvsp[-3].sVal)); free((yyvsp[-2].sVal)); }
 #line 1597 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 49:
-#line 237 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 237 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     {OpenIcons();}
 #line 1603 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 50:
-#line 237 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 237 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     {CloseIcons();}
 #line 1609 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 51:
-#line 240 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 240 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_TOPMOST; }
 #line 1615 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 52:
-#line 241 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 241 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_MAXIMIZE; }
 #line 1621 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 53:
-#line 242 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 242 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_MINIMIZE; }
 #line 1627 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 54:
-#line 243 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 243 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_BOTTOM; }
 #line 1633 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 55:
-#line 246 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 246 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_NOTITLE; }
 #line 1639 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 56:
-#line 247 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 247 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_OUTLINE; }
 #line 1645 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 57:
-#line 248 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 248 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_NOFRAME; }
 #line 1651 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 58:
-#line 251 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 251 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=STYLE_SKIPTASKBAR; }
 #line 1657 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 59:
-#line 254 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 254 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[0].uVal); }
 #line 1663 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 60:
-#line 255 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 255 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[0].uVal); }
 #line 1669 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 61:
-#line 256 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 256 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[0].uVal); }
 #line 1675 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 62:
-#line 257 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 257 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1681 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 63:
-#line 258 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 258 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1687 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 64:
-#line 259 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 259 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1693 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 65:
-#line 260 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 260 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1699 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 66:
-#line 261 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 261 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1705 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 67:
-#line 262 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 262 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1711 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 68:
-#line 263 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 263 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1717 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 69:
-#line 264 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 264 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1723 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 70:
-#line 265 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 265 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1729 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 71:
-#line 266 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 266 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1735 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 72:
-#line 267 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 267 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1741 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 73:
-#line 268 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 268 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.uVal)=(yyvsp[-2].uVal)|(yyvsp[-1].uVal)|(yyvsp[0].uVal); }
 #line 1747 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 74:
-#line 271 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 271 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { AddStyleLine((yyvsp[-3].sVal), (yyvsp[-2].uVal)); free((yyvsp[-3].sVal)); }
 #line 1753 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 77:
-#line 278 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 278 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     {OpenStyles();}
 #line 1759 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 78:
-#line 278 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 278 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     {CloseStyles();}
 #line 1765 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 79:
-#line 281 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 281 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.iVal)=AT_END; }
 #line 1771 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 80:
-#line 282 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 282 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.iVal)=AT_START; }
 #line 1777 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 81:
-#line 283 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 283 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { (yyval.iVal)=AT_END; }
 #line 1783 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 82:
-#line 286 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 286 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { AddSysMenuLine((yyvsp[-4].sVal), (yyvsp[-3].sVal), (yyvsp[-2].iVal)); free((yyvsp[-4].sVal)); free((yyvsp[-3].sVal)); }
 #line 1789 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 85:
-#line 293 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 293 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     {OpenSysMenu();}
 #line 1795 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 86:
-#line 293 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 293 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     {CloseSysMenu();}
 #line 1801 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 87:
-#line 296 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 296 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { pref.fForceExit = TRUE; }
 #line 1807 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 88:
-#line 299 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 299 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { pref.fSilentExit = TRUE; }
 #line 1813 "winprefsyacc.c" /* yacc.c:1646  */
     break;
 
   case 89:
-#line 302 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
+#line 302 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1646  */
     { ErrorF("LoadPreferences: %s\n", (yyvsp[-1].sVal)); free((yyvsp[-1].sVal)); }
 #line 1819 "winprefsyacc.c" /* yacc.c:1646  */
     break;
@@ -2047,7 +2047,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 306 "/wip/cygport-git/xorg-server/xorg-server-1.18.4-1.i686/src/xserver-cygwin-1.18.4-1/hw/xwin/winprefsyacc.y" /* yacc.c:1906  */
+#line 306 "/wip/cygport-git/xorg-server/xorg-server-1.19.6-2.x86_64/src/xserver-cygwin-1.19.6-2/hw/xwin/winprefsyacc.y" /* yacc.c:1906  */
 
 /*
  * Errors in parsing abort and print log messages
